ChatContextMenuWrapper class

Inheritance

Constructors

ChatContextMenuWrapper({Key? key, required ContextMenuWidgetBuilder widgetBuilder, required ContextMenuContentBuilder menuBuilder, Color barrierColor = Colors.transparent, Color? backgroundColor, BorderRadius borderRadius = const BorderRadius.all(Radius.circular(8)), EdgeInsets padding = const EdgeInsets.all(8), bool requestFocus = false, List<BoxShadow>? shadows, double arrowHeight = 8.0, double arrowWidth = 12.0, double spacing = 6.0, Widget? transitionsBuilder(BuildContext context, Animation<double> animation, Animation<double> secondaryAnimation, Offset centerOffset, Alignment alignment, Widget child)?, Duration transitionDurations = const Duration(milliseconds: 150), void onClose(dynamic result)?, double horizontalMargin = 10.0, BoxConstraints? menuConstraints, BoxConstraints? layoutConstraints, Axis axis = Axis.vertical, double topPadding = kToolbarHeight, bool excludeAnchorFromBarrier = false, EdgeInsets barrierAnchorPadding = EdgeInsets.zero, BorderRadius? barrierAnchorBorderRadius})
const

Properties

arrowHeight double
角标的高度 The height of the marker
final
arrowWidth double
角标的宽度 The width of the marker
final
axis Axis
排列方向 Arrangement direction
final
backgroundColor Color?
context menu容器的背景颜色。 也作用于角标的颜色 Background color of the menu container. Also affects the color of the marker
final
barrierAnchorBorderRadius BorderRadius?
Optional corner radii for the cutout; match your bubble BoxDecoration.borderRadius.
final
barrierAnchorPadding EdgeInsets
Inflates the barrier cutout around the measured anchor rectangle.
final
barrierColor Color
屏障颜色 (背景叠加层的颜色。) Color of the background overlay.
final
borderRadius BorderRadius
context menu容器的圆角 Rounded corners of context menu container
final
excludeAnchorFromBarrier bool
When true, the modal barrier omits anchor widgetRect (plus barrierAnchorPadding) so it stays visible and interactive like the floating menu surface. Default is false (full-screen barrier).
final
hashCode int
The hash code for this object.
no setterinherited
horizontalMargin double
距屏幕左右的最小留白 Minimum horizontal margin from screen edges
final
key Key?
Controls how one widget replaces another widget in the tree.
finalinherited
layoutConstraints BoxConstraints?
可用屏幕区域的约束(用于布局判定) Constraints of available screen space (for layout decisions)
final
显示的 context menu 组件 Displayed context menu widget
final
context menu容器的约束 Constraints of context menu container
final
onClose → void Function(dynamic result)?
关闭时触发的回调 Callback triggered when closed
final
padding EdgeInsets
context menu容器的内边距 Padding corners of context menu container
final
requestFocus bool
是否在显示的的时候获取焦点 默认为 false 如果为 true 那么在context menu显示的时候你页面中的其他具有焦点的组件将失去焦点 Whether to get focus when displayed The default is false. If it is true, other focused components in your page will lose focus when the context menu is displayed.
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
shadows List<BoxShadow>?
context menu容器的阴影 Shadows corners of context menu container
final
spacing double
context menu 和组件的间距 Spacing between context menu and components
final
topPadding double
顶部安全区域的额外边距 默认为 kToolbarHeight,当在 AppBar 中使用时可设为 0 Extra padding for top safe area Defaults to kToolbarHeight, can be set to 0 when used inside AppBar
final
transitionDurations Duration
菜单动画时长 Duration of menu animation
final
transitionsBuilder Widget? Function(BuildContext context, Animation<double> animation, Animation<double> secondaryAnimation, Offset centerOffset, Alignment alignment, Widget child)?
自定义出现的动画 Customize the animation that appears
final
widgetBuilder ContextMenuWidgetBuilder
在页面中显示的组件 Components displayed on the page
final

Methods

createElement() StatefulElement
Creates a StatefulElement to manage this widget's location in the tree.
inherited
createState() State<ChatContextMenuWrapper>
Creates the mutable state for this widget at a given location in the tree.
override
debugDescribeChildren() List<DiagnosticsNode>
Returns a list of DiagnosticsNode objects describing this node's children.
inherited
debugFillProperties(DiagnosticPropertiesBuilder properties) → void
Add additional properties associated with the node.
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toDiagnosticsNode({String? name, DiagnosticsTreeStyle? style}) DiagnosticsNode
Returns a debug representation of the object that is used by debugging tools and by DiagnosticsNode.toStringDeep.
inherited
toString({DiagnosticLevel minLevel = DiagnosticLevel.info}) String
A string representation of this object.
inherited
toStringDeep({String prefixLineOne = '', String? prefixOtherLines, DiagnosticLevel minLevel = DiagnosticLevel.debug, int wrapWidth = 65}) String
Returns a string representation of this node and its descendants.
inherited
toStringShallow({String joiner = ', ', DiagnosticLevel minLevel = DiagnosticLevel.debug}) String
Returns a one-line detailed description of the object.
inherited
toStringShort() String
A short, textual description of this widget.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited