MobileTriggerMode enum

移动端菜单触发方式 Menu trigger mode for mobile platforms

Inheritance
Available extensions

Values

tap → const MobileTriggerMode

单击触发 Trigger on single tap

doubleTap → const MobileTriggerMode

双击触发 Trigger on double tap

longPress → const MobileTriggerMode

长按触发 Trigger on long press

Properties

hashCode int
The hash code for this object.
no setterinherited
index int
A numeric identifier for the enumerated value.
no setterinherited
name String

Available on Enum, provided by the EnumName extension

The name of the enum value.
no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Constants

values → const List<MobileTriggerMode>
A constant List of the values in this enum, in order of their declaration.